function [K_Bar, M_Bar, N_Bar] = RESOLME_Bar_expm(P, n_ME, L_ME, G_ME, e_ME, b, t_ME, E_ME)
% =========================================================================
% SYSTEM OF FIRST ORDER DIFFERENTIAL EQUATIONS
% =========================================================================
% [N1(0)...NP(0) u1(0)...uP(0) N1(L)...NP(L) u1(L)...uP(L)
% =========================================================================

    AA = zeros(2*P,2*P,n_ME);
    for inc = 1:n_ME
        L=L_ME(inc,1);
% (1,P x P+1,2P) Part of A Matrix from the Local Equilibrium Equations
% dNi/dx = f(ui)
            AA(1,P+1,inc) = (G_ME(1)/t_ME(1))*b;
            AA(1,P+2,inc) = -(G_ME(1)/t_ME(1))*b;
            for i=2:(P-1)
                AA(i,P+i-1,inc) = -(G_ME(i-1)/t_ME(i-1))*b;
                AA(i,P+i,inc) = ((G_ME(i-1)/t_ME(i-1))+(G_ME(i)/t_ME(i)))*b;
                AA(i,P+i+1,inc) = -(G_ME(i)/t_ME(i))*b;
            end 
            AA(P,2*P-1,inc) = -(G_ME(P-1)/t_ME(P-1))*b;
            AA(P,2*P,inc) = -AA(P,2*P-1);
% (P+1,2P x 1,P) Part of A Matrix from the Constitutive Eq.s of the Adherends
% dui/dx = f(Ni)
            for i=1:P
                AA(i+P,i,inc) =  1/(E_ME(i)*b*e_ME(i));
            end 
% %%%%%% END OF THE SYSTEM OF FIRST ORDER DIFFERENTIAL EQUATIONS %%%%%%%%%%
% =========================================================================
% The Solution of the System of First-Order ODEs with "expm"
% ========================================================================= 
% Y(x) = EXPM(Ax)*Y0

% Fundamental Matrix
%%% syms L
%PHI = sym(zeros(2*P,2*P));

% SOL_Lminus is at x=0
% SOL_Lplus is at x=L
% SOL_Lminus = expm(AA*0);
% SOL_Lplus = expm(AA*L); 
% =========================================================================
    A(1:2*P,1:2*P)=AA(1:2*P,1:2*P,inc);

% 1st step
        PHI = zeros(2*P,2*P);
        SOL_Lminus = phi_t(A,0);
        SOL_Lplus = phi_t(A,L);

% 2nd step
% Distribution of SOL Between Displacement (U) and Force (F)
% Displacement
    SOL_U_Lminus = zeros(P,2*P);
    SOL_U_Lplus = zeros(P,2*P);
% Force
    SOL_F_Lminus = zeros(P,2*P);
    SOL_F_Lplus = zeros(P,2*P);

        for i=1:P
            for j=1:2*P
                SOL_F_Lminus(i,j)=SOL_Lminus(i,j);
                SOL_F_Lplus(i,j)=SOL_Lplus(i,j);
                SOL_U_Lminus(i,j)=SOL_Lminus(i+P,j);
                SOL_U_Lplus(i,j)=SOL_Lplus(i+P,j);        
            end   
        end

% 3rd step
% At both extermities for each layer according to 
% [u10 u20 ... uP0 u1L u2L ... uPL]
% [N10 N20 ... NP0 N1L N2L ... NPL]

    SOL_U_temp = zeros(2*P,2*P);
    SOL_F_temp = zeros(2*P,2*P);

        for i=1:P
            for j=1:2*P
                SOL_U_temp(i,j) = SOL_U_Lminus(i,j);
                SOL_U_temp(i+P,j) = SOL_U_Lplus(i,j);
                SOL_F_temp(i,j) = SOL_F_Lminus(i,j);
                SOL_F_temp(i+P,j) = SOL_F_Lplus(i,j);  
            end
        end 

% Reordering
% According to 
% [u10 u1L u20 u2L ... uP0 uPL]
% [N10 N1L N20 N2L ... NP0 NPL]


% M-Matrix     
    SOL_U = zeros(2*P,2*P);
    for i = 1:P
        SOL_U(2*i-1,1:2*P) = SOL_U_temp(i,1:2*P);
        SOL_U(2*i,1:2*P) = SOL_U_temp(i+P,1:2*P);
    end
    M = SOL_U;

% N-Matrix
    SOL_F = zeros(2*P,2*P);
    for i = 1:P
        SOL_F(2*i-1,1:2*P) = -SOL_F_temp(i,1:2*P);
        SOL_F(2*i,1:2*P) = SOL_F_temp(i+P,1:2*P);
    end
    N = SOL_F;

% 4th step
% K - Stiffness Matrix of Elements
    KK_Bar = zeros(2*P,2*P);

    canonic = zeros(2*P,1);
        for i=1:2*P
            canonic = zeros(2*P,1);
            canonic(i,1) = 1;
            cons=inv(SOL_U)*canonic;
            resultant = SOL_F*cons;
            KK_Bar(1:2*P,i)=resultant;
        end
    
    K_Bar(1:2*P,1:2*P,inc) = KK_Bar(1:2*P,1:2*P);
    M_Bar(1:2*P,1:2*P,inc) = M(1:2*P,1:2*P);
    N_Bar(1:2*P,1:2*P,inc) = N(1:2*P,1:2*P);
    
    end
end 