function [Ke,Me,Ne] = MEXGR(n_elem,n_P,b,h,kI,kII,Ao,Do,L)
    
    Ke=zeros(6*n_P,6*n_P,n_elem);
    Me=zeros(6*n_P,6*n_P,n_elem);
    Ne=zeros(6*n_P,6*n_P,n_elem);

        AA=zeros(6*n_P,6*n_P,n_elem);
    
        for inc=1:n_elem
           
            % COUPLED SYSTEM OF FIRST ORDER DIFFERENTIAL EQUATIONS
            % [N1 Ni NP V1 Vi VP M1 Mi MP u1 ui uP w1 vi vP q1 qi qP]
            
                % dN1 % A(1,:) = local equilibrium equation of adherend 1 according to the x-axis
                AA(1,3*n_P+1,inc) = b(1,inc)*kII(1,inc);                                     %u1
                AA(1,3*n_P+2,inc) = -b(1,inc)*kII(1,inc);                                    %u2
                AA(1,5*n_P+1,inc) = b(1,inc)*h(1,inc)*kII(1,inc);                              %q1
                AA(1,5*n_P+2,inc) = b(1,inc)*h(2,inc)*kII(1,inc);                              %q2

                % dNi % local equilibrium equation of adherend i according to the x-axis
               for j=2:n_P-1
                    AA(j,3*n_P+j-1,inc) = -b(1,inc)*kII(j-1,inc);                              %ui-1
                    AA(j,3*n_P+j,inc) = b(1,inc)*kII(j-1,inc)+b(1,inc)*kII(j,inc);             %ui
                    AA(j,3*n_P+j+1,inc) = -b(1,inc)*kII(j,inc);                                %ui+1
                    AA(j,5*n_P+j-1,inc) = -b(1,inc)*h(j-1,inc)*kII(j-1,inc);                     %qi-1
                    AA(j,5*n_P+j,inc) = -b(1,inc)*h(j,inc)*kII(j-1,inc)+b(1,inc)*h(j,inc)*kII(j,inc);     %qi
                    AA(j,5*n_P+j+1,inc) = b(1,inc)*h(j+1,inc)*kII(j,inc);                        %qi+1
               end

                % dNP % local equilibrium equation of adherend P according to the x-axis
                AA(n_P,3*n_P+n_P-1,inc) = -b(1,inc)*kII(n_P-1,inc);                            %uP-1
                AA(n_P,3*n_P+n_P,inc) = b(1,inc)*kII(n_P-1,inc);                               %uP
                AA(n_P,5*n_P+n_P-1,inc) = -b(1,inc)*h(n_P-1,inc)*kII(n_P-1,inc);                 %qP-1
                AA(n_P,5*n_P+n_P,inc) = -b(1,inc)*h(n_P,inc)*kII(n_P-1,inc);                     %qP

                % dV1 % local equilibrium equation of adherend 1 according to the y-axis
                AA(n_P+1,4*n_P+1,inc) = b(1,inc)*kI(1,inc);                                    %w1
                AA(n_P+1,4*n_P+2,inc) = -b(1,inc)*kI(1,inc);                                   %w2

                % dVi % A(3*(j-1)+2,:) = local equilibrium equation of adherend i according to the y-axis
                for j=2:n_P-1
                    AA(n_P+j,4*n_P+j-1,inc) = -b(1,inc)*kI(j-1,inc);                           %wi-1
                    AA(n_P+j,4*n_P+j,inc) = b(1,inc)*kI(j-1,inc)+b(1,inc)*kI(j,inc);           %wi
                    AA(n_P+j,4*n_P+j+1,inc) = -b(1,inc)*kI(j,inc);                             %wi+1
                end

                % dVP % local equilibrium equation of adherend P according to the y-axis
                AA(2*n_P,4*n_P+n_P-1,inc) = -b(1,inc)*kI(n_P-1,inc);                           %wP-1
                AA(2*n_P,4*n_P+n_P,inc) = b(1,inc)*kI(n_P-1,inc);                              %wP
            

                % dM1 % local equilibrium equation of adherend 1 according to the z-axis
                AA(2*n_P+1,n_P+1,inc) = -1;
                AA(2*n_P+1,3*n_P+1,inc) = b(1,inc)*h(1,inc)*kII(1,inc);                          %u1
                AA(2*n_P+1,3*n_P+2,inc) = -b(1,inc)*h(1,inc)*kII(1,inc);                         %u2
                AA(2*n_P+1,5*n_P+1,inc) = b(1,inc)*h(1,inc)*h(1,inc)*kII(1,inc);                   %q1
                AA(2*n_P+1,5*n_P+2,inc) = b(1,inc)*h(1,inc)*h(2,inc)*kII(1,inc);                   %q2

                for j=2:n_P-1
                % dMi % local equilibrium equation of adherend i according to the z-axis
                    AA(2*n_P+j,n_P+j,inc) = -1;                                         %Vi
                    AA(2*n_P+j,3*n_P+j-1,inc) = b(1,inc)*h(j,inc)*kII(j-1,inc);                  %ui-1
                    AA(2*n_P+j,3*n_P+j,inc) = b(1,inc)*h(j,inc)*(kII(j,inc)-kII(j-1,inc));       %ui
                    AA(2*n_P+j,3*n_P+j+1,inc) = -b(1,inc)*h(j,inc)*kII(j,inc);                   %ui+1
                    AA(2*n_P+j,5*n_P+j-1,inc) = b(1,inc)*h(j-1,inc)*h(j,inc)*kII(j-1,inc);         %qi-1
                    AA(2*n_P+j,5*n_P+j,inc) = b(1,inc)*h(j,inc)*h(j,inc)*(kII(j-1,inc)+kII(j,inc));%qi
                    AA(2*n_P+j,5*n_P+j+1,inc) = b(1,inc)*h(j+1,inc)*h(j,inc)*kII(j,inc);           %qi+1
                end

                % dMP % local equilibrium equation of adherend P according to the z-axis
                AA(3*n_P,2*n_P,inc) = -1;
                AA(3*n_P,3*n_P+n_P-1,inc) = b(1,inc)*h(n_P,inc)*kII(n_P-1,inc);                  %uP-1
                AA(3*n_P,3*n_P+n_P,inc) = -b(1,inc)*h(n_P,inc)*kII(n_P-1,inc);                   %uP
                AA(3*n_P,5*n_P+n_P-1,inc) = b(1,inc)*h(n_P,inc)*h(n_P-1,inc)*kII(n_P-1,inc);     %qP-1
                AA(3*n_P,5*n_P+n_P,inc) = b(1,inc)*h(n_P,inc)*h(n_P,inc)*kII(n_P-1,inc);         %qP

                for j=1:n_P
                    % constitutive equation on dui
                    AA(3*n_P+j,j,inc) = 1/Ao(j,inc);                            %Ni
                    % constitutive equation on dwi
                    AA(4*n_P+j,5*n_P+j,inc) = 1;                                %Vi
                    % constitutive equation on dqi
                    AA(5*n_P+j,2*n_P+j,inc) = 1/Do(j,inc);                        %Mi
                end
            % END OF COUPLED SYSTEM OF FIRST ORDER DIFFERENTIAL EQUATIONS
                        
            
            Lo=L(1,inc); 
            
            A(1:6*n_P,1:6*n_P)=AA(1:6*n_P,1:6*n_P,inc);
            PHI=zeros(6*n_P,6*n_P);
            SOL_Lplus=phi_t(A,Lo);
            SOL_Lmoins=phi_t(A,0);
            
            %DISTRIBUTION OF SOL BETWEEN DISPLAMCEMENT AND FORCE
            SOL_U_Lplus=zeros(3*n_P,6*n_P);
            SOL_U_Lmoins=zeros(3*n_P,6*n_P);
            SOL_F_Lplus=zeros(3*n_P,6*n_P);
            SOL_F_Lmoins=zeros(3*n_P,6*n_P);
            for i=1:3*n_P
                for j=1:6*n_P
                    SOL_F_Lplus(i,j)=SOL_Lplus(i,j);
                    SOL_F_Lmoins(i,j)=SOL_Lmoins(i,j);
                    SOL_U_Lplus(i,j)=SOL_Lplus(i+3*n_P,j);        
                    SOL_U_Lmoins(i,j)=SOL_Lmoins(i+3*n_P,j);
                end
            end
            
            % AT BOTH EXTERMITIES ACCORDING TO
            %u10 uP0 w10 wP0 q10 qP0 u1L uPL w1L WPL q1L qPL 
            %N10 NP0 V10 VP0 M10 MP0 N1L NPL V1L VPL M1L MPL 
            SOL_U_temp=zeros(6*n_P,6*n_P);
            SOL_F_temp=zeros(6*n_P,6*n_P);
            for i=1:3*n_P
                 for j=1:6*n_P
                    SOL_U_temp(i+3*n_P,j)=SOL_U_Lplus(i,j);
                    SOL_U_temp(i,j)=SOL_U_Lmoins(i,j);
                    SOL_F_temp(i+3*n_P,j)=SOL_F_Lplus(i,j);
                    SOL_F_temp(i,j)=SOL_F_Lmoins(i,j);
                end
            end
            
            % THEN ACCORDING TO
            % u10 uP0 u1L uPL w10 wP0 w1L wPL q10 qP0 q1L qPL 
            % -N10 -NP0 N1L NPL -V10 -VP0 V1L VPL -M10 -MP0 M1L MPL 
            SOL_U=zeros(6*n_P,6*n_P);         % M MATRIX
            SOL_F=zeros(6*n_P,6*n_P);         % N MATRIX

            for j=1:n_P
                SOL_U(j,1:6*n_P) = SOL_U_temp(j,1:6*n_P);
                SOL_U(n_P+j,1:6*n_P) = SOL_U_temp(3*n_P+j,1:6*n_P);
                SOL_U(2*n_P+j,1:6*n_P) = SOL_U_temp(n_P+j,1:6*n_P);
                SOL_U(3*n_P+j,1:6*n_P) = SOL_U_temp(4*n_P+j,1:6*n_P);
                SOL_U(4*n_P+j,1:6*n_P) = SOL_U_temp(2*n_P+j,1:6*n_P);
                SOL_U(5*n_P+j,1:6*n_P) = SOL_U_temp(5*n_P+j,1:6*n_P);
            end
            for j=1:n_P
                SOL_F(j,1:6*n_P) = -SOL_F_temp(j,1:6*n_P);
                SOL_F(n_P+j,1:6*n_P) = SOL_F_temp(3*n_P+j,1:6*n_P);
                SOL_F(2*n_P+j,1:6*n_P) = -SOL_F_temp(n_P+j,1:6*n_P);
                SOL_F(3*n_P+j,1:6*n_P) = SOL_F_temp(4*n_P+j,1:6*n_P);
                SOL_F(4*n_P+j,1:6*n_P) = -SOL_F_temp(2*n_P+j,1:6*n_P);
                SOL_F(5*n_P+j,1:6*n_P) = SOL_F_temp(5*n_P+j,1:6*n_P);
            end
            
            for i=1:6*n_P
                canonic=zeros(6*n_P,1);
                canonic(i,1)=1;
                cons=SOL_U\canonic;
                resultant=SOL_F*cons;
                KK_PC(1:6*n_P,i)=resultant;
            end
        
        Ke(1:6*n_P,1:6*n_P,inc) = KK_PC(1:6*n_P,1:6*n_P);
        Me(1:6*n_P,1:6*n_P,inc) = SOL_U(1:6*n_P,1:6*n_P);
        Ne(1:6*n_P,1:6*n_P,inc) = SOL_F(1:6*n_P,1:6*n_P);
        
           
        end
 
end